Accepts the hexadecimal code vector and tests if it is formatted correctly
Examples
# Check for misformatted hexcodes
palette_check(palette = c("#8e847a", "#9fc7f2"))
Accepts the hexadecimal code vector and tests if it is formatted correctly
# Check for misformatted hexcodes
palette_check(palette = c("#8e847a", "#9fc7f2"))